@@ -1,4 +1,4 @@
-__version__="3.8.0"
+__version__="3.8.1"
 
 import sys
 from .kerasmodel import KerasModel
@@ -8,5 +8,5 @@ from .utils import seed_everything
 try:
     from .lightmodel import LightModel 
 except Exception:
-    print("torchkeras.LightModel can't be used!",file = sys.stderr)
+    pass
 
